Examples
========

.. toctree::
   :maxdepth: 2
   :caption: List:

   examples/00_setup
   examples/01_run_openlane_flow
   examples/01a_parametric_openlane_designs
   examples/01b_gdsfactory_layout_integration
   examples/01c_openlane_design_report_analysis
   examples/02_cocotb_simulation
   examples/03_sax_basics
   examples/03a_sax_cocotb_cosimulation
   examples//04_spice_cosimulation/04_spice_cosimulation
   examples/04a_mixed_signal_photonic_cosimulation
   examples/05_quantum_integration_basics
   examples/06_component_codesign_basics
